# -*- coding: utf-8 -*-

"""Main module."""
import os
from subprocess import run as shell_run

current_path = os.path.dirname(os.path.abspath(__file__))


def merge_docx(result_docx, *merging_docx):
    cmd_script = ['php', '{}/engine/merge_docx.php'.format(current_path), ] + list(merging_docx) + [result_docx, ]
    shell_result = shell_run(cmd_script)
    return shell_result



# -*- coding: utf-8 -*-

"""Top-level package for pymergedocx."""

from .pymergedocx import merge_docx

__author__ = """x-debug"""
__email__ = '512766594@qq.com'
__version__ = '0.1.0'
__all__ = ['merge_docx']



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `pymergedocx` package."""

import os
import unittest
from click.testing import CliRunner
from pymergedocx import pymergedocx
from pymergedocx import cli, merge_docx

current_path = os.path.dirname(os.path.abspath(__file__))


class TestPymergedocx(unittest.TestCase):
    """Tests for `pymergedocx` package."""

    def setUp(self):
        """Set up test fixtures, if any."""

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_000_something(self):
        """Test something."""
        merge_docx('{}/files/result.docx'.format(current_path), '{}/files/template.docx'.format(current_path),
                   '{}/files/template1.docx'.format(current_path), '{}/files/template2.docx'.format(current_path))

    def test_command_line_interface(self):
        """Test the CLI."""
        runner = CliRunner()
        result = runner.invoke(cli.main)
        assert result.exit_code == 0
        assert 'pymergedocx.cli.main' in result.output
        help_result = runner.invoke(cli.main, ['--help'])
        assert help_result.exit_code == 0
        assert '--help  Show this message and exit.' in help_result.output
